---
vid: KHV022
title: Critical Privilege Escalation CVE
categories: [Privilege Escalation]
---

# {{ page.vid }} - {{ page.title }}

## Issue description

Cluster is found to be vulnerable to CVE-2018-1002105. Please see the Vulnerability description for additional information.

## Remediation

Please see the Vulnerability description for remediation.

## References

- [Severe Privilege Escalation Vulnerability in Kubernetes (CVE-2018-1002105)](https://blog.aquasec.com/kubernetes-security-cve-2018-1002105)